cd "H:\0000.MCS\July merge datasets"
use "CleanData_FCMJ", clear

*Setting up survey weights
svyset [pweight=COVWT1], strata(PTTYPE2)

*Install package for looking at extreme outliers
ssc install extremes

***********************************************************
*************Recoding/renaming some variables**************
***********************************************************

*Recoded so I can treat the no qualifications as below NVQ 1 and to remove oversas qualifications (they don't really fit in here as a ranked category)
*-3 and -2 codes from previous dataset no longer relevant here (and have no Ps), so not included
*Also renamed to remove the _W2
rename MatEdu_W2 MatEdu
tab MatEdu
recode MatEdu (-1=-1) (1=1) (2=2) (3=3) (4=4) (5=5) (95=-4) (96=0) (.=-98)
label define NVQ -98 "no maternal edu data avaialble" -4 "Overseas qual" -1 "Not applicable" 0 "No NVQ qualifications" 1 "NVQ level 1" 2 "NVQ level 2" 3 "NVQ level 3" 4 "NVQ level 4" 5 "NVQ level 5", replace
tab MatEdu


*OECD 60% poverty median
*Also renamed to clarify variable
rename Family60MedW2 Pov60Med
tab Pov60Med
recode Pov60Med (1=0) (0=1)
label define OECD -1 "Not applicable/missing" 1 "above 60% median" 0 "below 60% median", replace
tab Pov60Med


*Removed _M and _W2 from HLE index and SDQ respectively. Clearer, simpler names for IMDLE, BSRAR, BAS-2 NV and age 
rename HLEINDEX_M HLEINDEX
rename SDQTotal_W2 SDQT
rename BAS_NV_Standard_W2 BAS2NVT
rename Age_InMonths_W2 AgeMo
rename BSRAR_Standard BSRAR

*Renaming the other FSPT subsections for ease
rename CC_DA DA
rename CC_SD SD
rename CC_ED ED
rename CC_LCT LCT
rename CC_LSL LSL
rename CC_R READ
rename CC_W WRIT
rename CC_NLC NLC
rename CC_C CALC
rename CC_SSM SSM
rename CC_ZDA DAZ
rename CC_ZSD SDZ
rename CC_ZED EDZ
rename CC_ZLCT LCTZ
rename CC_ZLSL LSLZ
rename CC_ZREADING READZ
rename CC_ZWRITE WRITZ
rename CC_ZNLC NLCZ
rename CC_ZCALC CALCZ
rename CC_ZSSM SSMZ

*Renamed the MH measure for more streamline
rename MatK6MH_W2 MatMH

*Setting up logistic regression - Good level of development
*7 subsections for Personal, social and emotional development + Communication, language and literacy
*0 = GLD not met, 1 = met
****n=4,194 GLD not met, n=3,567 GLD met
****n=2,039 which did not meet GLD got 78+
gen FSPGLD = 0 if FSPT !=.
replace FSPGLD = 1 if DA >=6 & SD >=6 & ED >=6 & LCT >=6 & LSL >=6 & READ >=6 & WRIT >=6 & FSPT >=78
tab FSPT FSPGLD
count if FSPT >=78 & FSPGLD ==0



********************************************************************************
*************************Further drops******************************************
********************************************************************************

*when tabbing these, there was a small number of children which had missing scores on certain subcategories. As I am removing those without FSP scores, I'm also going to remove these.
****Removed n=5 children
*1 dropped
drop if DA ==.
drop if SD ==.
drop if ED ==.
drop if PSE ==.
*dropped 1
drop if LCT ==.
*dropped 1
drop if LSL ==.
*dropped 1
drop if READ ==.
drop if WRIT ==.
drop if CLL ==.
drop if NLC ==.
drop if CALC ==.
*dropped 1
drop if SSM ==.
drop if MD ==.
drop if KUW ==.
drop if PD ==.
drop if CD ==.

*Removing children which did not have predictor (BAS-2 NV) values
tab BAS2NVT
drop if BAS2NVT == -8 | BAS2NVT == -7 | BAS2NVT == -6
tab BAS2NVT

*I then removed any CMs who had mothers with overseas qualifications as when I later want to impute data -- and I can't treat these as missing or include this category.
drop if MatEdu ==-4
tab MatEdu


********************************************************************************
*********Setting up variables for analysis: No response = missing***************
********************************************************************************


*Making any missing values =. to simplify syntax and for later non-casewise deletion analysis
*Not needed for BAS-2 NV and FSP, as Ps were previously removed if they did not have score
*Gender assigned at birth had no missing values, so no edits needed
replace BSRAR =. if BSRAR <=-1
replace AgeMo =. if AgeMo <=-1
replace SDQT =. if SDQT <=-1
replace Pov60Med =. if Pov60Med <=-1
replace MatEdu =. if MatEdu <=-1
replace HLEINDEX =. if HLEINDEX <=-1
replace MatMH =. if MatMH <=-1
replace Age_InDays_W2 =. if Age_InDays_W2<=-1


tab BAS2NVT
tab BSRAR
tab AgeMo
tab GENDERAAB
tab SDQT
tab Pov60Med
tab MatEdu
tab HLEINDEX
tab MatMH
tab MatAgeBirth

*Generating a variable to compare those with all variable data versus those with partial data (i.e. at least 1 variable with missing data)
gen Alldata = 1 if BAS2NVT !=.
replace Alldata = 0 if GENDERAAB ==. | Pov60Med ==. | BSRAR ==. | AgeMo ==. | SDQT ==. | MatEdu ==. | MatMH ==. | MatAgeBirth ==. | HLEINDEX ==.
tab Alldata
count if Alldata ==.

********************************************************************************
**********************Descriptive/initial stats ***************************
********************************************************************************
****All/Partial/Full descriptive and initial analyses

*BAS-2 NV - All
sum(BAS2NVT), detail
ci mean BAS2NVT
hist(BAS2NVT), frequency normal bin(15)
*BAS-2 NV - Partial and full data
sum(BAS2NVT) if Alldata ==0, detail
hist(BAS2NVT) if Alldata ==0, frequency normal bin(15)
sum(BAS2NVT) if Alldata ==1, detail
hist(BAS2NVT) if Alldata ==1, frequency normal bin(15)
*Adjusted mean and SD by MCS weights and strata All/Partial/Full
svy: mean BAS2NVT
svy: mean BAS2NVT, over(Alldata)
*t-test difference in BAS-2 NV between those with full and partial data - unadjusted 
ttest BAS2NVT, by(Alldata)
*t-test adjusted 
svy: mean BAS2NVT, over(Alldata) coeflegend
lincom _b[c.BAS2NVT@0bn.Alldata] - _b[c.BAS2NVT@1.Alldata]


*FSP total
sum(FSPT), detail
ci mean FSPT
hist(FSPT), frequency normal bin(10)
*FSP total - Partial and full data
sum(FSPT) if Alldata ==0, detail
hist(FSPT) if Alldata ==0, frequency normal bin(10)
sum(FSPT) if Alldata ==1, detail
hist(FSPT) if Alldata ==1, frequency normal bin(10)
*Adjusted mean and SD by MCS weights and strata All/Partial/Full
svy: mean FSPT 
svy: mean FSPT, over(Alldata)
*t-test difference in FSP total between those with full and partial data - unadjusted
ttest FSPT, by(Alldata)
*t-test adjusted 
svy: mean FSPT, over(Alldata) coeflegend
lincom _b[c.FSPT@0bn.Alldata] - _b[c.FSPT@1.Alldata]


*FSP personal, social and emotional development total
sum(PSE), detail
ci mean PSE
hist(PSE), frequency normal bin(28)
*FSP total - Partial and full data
sum(PSE) if Alldata ==0, detail
hist(PSE) if Alldata ==0, frequency normal bin(28)
sum(PSE) if Alldata ==1, detail
hist(PSE) if Alldata ==1, frequency normal bin(28)
*Adjusted mean and SD by MCS weights and strata All/Partial/Full
svy: mean PSE 
svy: mean PSE, over(Alldata)
*t-test difference in FSP total between those with full and partial data - unadjusted
ttest PSE, by(Alldata)
*t-test adjusted 
svy: mean PSE, over(Alldata) coeflegend
lincom _b[c.PSE@0bn.Alldata] - _b[c.PSE@1.Alldata]


*FSP communication, language and literacy total
sum(CLL), detail
ci mean CLL
hist(CLL), frequency normal bin(37)
*FSP communication, language and literacy total - Partial and full data
sum(CLL) if Alldata ==0, detail
hist(CLL) if Alldata ==0, frequency normal bin(37)
sum(CLL) if Alldata ==1, detail
hist(CLL) if Alldata ==1, frequency normal bin(37)
*Adjusted mean and SD by MCS weights and strata All/Partial/Full
svy: mean CLL 
svy: mean CLL, over(Alldata)
*t-test difference in FSP communication, language and literacy total between those with full and partial data - unadjusted only
ttest CLL, by(Alldata)
*t-test adjusted 
svy: mean CLL, over(Alldata) coeflegend
lincom _b[c.CLL@0bn.Alldata] - _b[c.CLL@1.Alldata]


*FSP mathematical development total
sum(MD), detail
ci mean MD
hist(MD), frequency normal bin(28)
*FSP mathematical development total - Partial and full data
sum(MD) if Alldata ==0, detail
hist(MD) if Alldata ==0, frequency normal bin(28)
sum(MD) if Alldata ==1, detail
hist(MD) if Alldata ==1, frequency normal bin(28)
*Adjusted mean and SD by MCS weights and strata All/Partial/Full
svy: mean MD 
svy: mean MD, over(Alldata)
*t-test difference in FSP mathematical development total between those with full and partial data - unadjusted
ttest MD, by(Alldata)
*t-test adjusted 
svy: mean MD, over(Alldata) coeflegend
lincom _b[c.MD@0bn.Alldata] - _b[c.MD@1.Alldata]


*FSP knowledge and understanding of the world total
sum(KUW), detail
ci mean KUW
hist(KUW), frequency normal bin(10)
*FSP knowledge and understanding of the world total - Partial and full data
sum(KUW) if Alldata ==0, detail
hist(KUW) if Alldata ==0, frequency normal bin(10)
sum(KUW) if Alldata ==1, detail
hist(KUW) if Alldata ==1, frequency normal bin(10)
*Adjusted mean and SD by MCS weights and strata All/Partial/Full
svy: mean KUW 
svy: mean KUW, over(Alldata)
*t-test difference in FSP knowledge and understanding of the world total between those with full and partial data - unadjusted
ttest KUW, by(Alldata)
*t-test adjusted 
svy: mean KUW, over(Alldata) coeflegend
lincom _b[c.KUW@0bn.Alldata] - _b[c.KUW@1.Alldata]


*FSP physical development total
sum(PD), detail
ci mean PD
hist(PD), frequency normal bin(10)
*FSP physical development total - Partial and full data
sum(PD) if Alldata ==0, detail
hist(PD) if Alldata ==0, frequency normal bin(10)
sum(PD) if Alldata ==1, detail
hist(PD) if Alldata ==1, frequency normal bin(10)
*Adjusted mean and SD by MCS weights and strata All/Partial/Full
svy: mean PD
svy: mean PD, over(Alldata)
*t-test difference in FSP physical development total between those with full and partial data - unadjusted
ttest PD, by(Alldata)
*t-test adjusted 
svy: mean PD, over(Alldata) coeflegend
lincom _b[c.PD@0bn.Alldata] - _b[c.PD@1.Alldata]


*FSP creative development total
sum(CD), detail
ci mean CD
hist(CD), frequency normal bin(10)
*FSP creative development total - Partial and full data
sum(CD) if Alldata ==0, detail
hist(CD) if Alldata ==0, frequency normal bin(10)
sum(CD) if Alldata ==1, detail
hist(CD) if Alldata ==1, frequency normal bin(10)
*Adjusted mean and SD by MCS weights and strata All/Partial/Full
svy: mean CD 
svy: mean CD, over(Alldata)
*t-test difference in FSP creative development total between those with full and partial data - unadjusted
ttest CD, by(Alldata)
*t-test adjusted 
svy: mean CD, over(Alldata) coeflegend
lincom _b[c.CD@0bn.Alldata] - _b[c.CD@1.Alldata]


*FSP good level of development
tab FSPGLD
*Gender AAB - Partial and full data
tab FSPGLD if Alldata ==0
tab FSPGLD if Alldata ==1
*Chi-square difference in gender AAB proportions between those with full and partial data - unadjusted only
tab FSPGLD Alldata, chi2 expected row
*chi-square adjusted 
svy: tabulate FSPGLD Alldata, row

*Gender assigned at birth
tab GENDERAAB 
*Gender AAB - Partial and full data
tab GENDERAAB if Alldata ==0
tab GENDERAAB if Alldata ==1
*Chi-square difference in gender AAB proportions between those with full and partial data - unadjusted only
tab GENDERAAB Alldata, chi2 expected row
*chi-square adjusted 
svy: tabulate GENDERAAB Alldata, row

*Relative poverty
tab Pov60Med
*OECD RP - Partial and full data
tab Pov60Med if Alldata ==0
tab Pov60Med if Alldata ==1
*Chi-square difference in OECD RP proportions between those with full and partial data - unadjusted only
tab Pov60Med Alldata, chi2 expected row
*chi-square adjusted 
svy: tabulate Pov60Med Alldata, row


*Initial school readiness (BSRAR)
sum(BSRAR), detail
ci mean BSRAR
hist(BSRAR), frequency normal bin(10)
*BSRAR - Partial and full data
sum(BSRAR) if Alldata ==0, detail
hist(BSRAR) if Alldata ==0, frequency normal bin(10)
sum(BSRAR) if Alldata ==1, detail
hist(BSRAR) if Alldata ==1, frequency normal bin(10)
*Adjusted mean and SD by MCS weights and strata All/Partial/Full
svy: mean BSRAR 
svy: mean BSRAR, over(Alldata)
*t-test difference in FSP total between those with full and partial data - unadjusted
ttest BSRAR, by(Alldata)
*t-test adjusted 
svy: mean BSRAR, over(Alldata) coeflegend
lincom _b[c.BSRAR@0bn.Alldata] - _b[c.BSRAR@1.Alldata]


*Age
*Correlation with predictor and outcome, in daty and months (30 days) to see if similar enough (yes) - unadjusted
corr BAS2NVT FSPT AgeMo Age_InDays_W2
*Initial statistics
sum(AgeMo), detail
ci mean AgeMo
hist(AgeMo), frequency normal bin(20)
*Age - Partial and full data
sum(AgeMo) if Alldata ==0, detail
hist(AgeMo) if Alldata ==0, frequency normal bin(20)
sum(AgeMo) if Alldata ==1, detail
hist(AgeMo) if Alldata ==1, frequency normal bin(20)
*Adjusted mean and SD by MCS weights and strata
svy: mean AgeMo 
svy: mean AgeMo, over(Alldata)
*t-test difference in FSP total between those with full and partial data - unadjusted
ttest AgeMo, by(Alldata)
*t-test adjusted 
svy: mean AgeMo, over(Alldata) coeflegend
lincom _b[c.AgeMo@0bn.Alldata] - _b[c.AgeMo@1.Alldata]


*Behaviour
sum(SDQT), detail
ci mean SDQT
hist(SDQT), frequency normal bin(32)
*Behaviour - Partial and full data
sum(SDQT) if Alldata ==0, detail
hist(SDQT) if Alldata ==0, frequency normal bin(32)
sum(SDQT) if Alldata ==1, detail
hist(SDQT) if Alldata ==1, frequency normal bin(32)
*Adjusted mean and SD by MCS weights and strata
svy: mean SDQT 
svy: mean SDQT, over(Alldata)
*t-test difference in Behaviour between those with full and partial data - unadjusted
ttest SDQT, by(Alldata)
*t-test adjusted 
svy: mean SDQT, over(Alldata) coeflegend
lincom _b[c.SDQT@0bn.Alldata] - _b[c.SDQT@1.Alldata]


*Maternal education
tab MatEdu
*Maternal education - Partial and full data
tab MatEdu if Alldata ==0
tab MatEdu if Alldata ==1
*Maternal education difference in gender AAB proportions between those with full and partial data - unadjusted only
tab MatEdu Alldata, chi2 expected row
*chi-square adjusted 
svy: tabulate MatEdu Alldata, row

*Maternal age at birth
sum(MatAgeBirth), detail
ci mean MatAgeBirth
hist(MatAgeBirth), frequency normal bin(40)
*Age - Partial and full data
sum(MatAgeBirth) if Alldata ==0, detail
hist(MatAgeBirth) if Alldata ==0, frequency normal bin(40)
sum(MatAgeBirth) if Alldata ==1, detail
hist(MatAgeBirth) if Alldata ==1, frequency normal bin(40)
*Adjusted mean and SD by MCS weights and strata
svy: mean MatAgeBirth 
svy: mean MatAgeBirth, over(Alldata)
*t-test difference in FSP total between those with full and partial data - unadjusted
ttest MatAgeBirth, by(Alldata)
*t-test adjusted 
svy: mean MatAgeBirth, over(Alldata) coeflegend
lincom _b[c.MatAgeBirth@0bn.Alldata] - _b[c.MatAgeBirth@1.Alldata]


*Maternal mental health (kessler-6)
sum(MatMH), detail
ci mean MatMH
hist(MatMH), frequency normal bin(24)
*Age - Partial and full data
sum(MatMH) if Alldata ==0, detail
hist(MatMH) if Alldata ==0, frequency normal bin(24)
sum(MatMH) if Alldata ==1, detail
hist(MatMH) if Alldata ==1, frequency normal bin(24)
*Adjusted mean and SD by MCS weights and strata
svy: mean MatMH 
svy: mean MatMH, over(Alldata)
*t-test difference in FSP total between those with full and partial data - unadjusted
ttest MatMH, by(Alldata)
*t-test adjusted 
svy: mean MatMH, over(Alldata) coeflegend
lincom _b[c.MatMH@0bn.Alldata] - _b[c.MatMH@1.Alldata]


*HLE index
sum(HLEINDEX), detail
ci mean HLEINDEX
hist(HLEINDEX), frequency normal bin(42)
*Age - Partial and full data
sum(HLEINDEX) if Alldata ==0, detail
hist(HLEINDEX) if Alldata ==0, frequency normal bin(42)
sum(HLEINDEX) if Alldata ==1, detail
hist(HLEINDEX) if Alldata ==1, frequency normal bin(42)
*Adjusted mean and SD by MCS weights and strata
svy: mean HLEINDEX 
svy: mean HLEINDEX, over(Alldata)
*t-test difference in FSP total between those with full and partial data - unadjusted
ttest HLEINDEX, by(Alldata)
*t-test adjusted 
svy: mean HLEINDEX, over(Alldata) coeflegend
lincom _b[c.HLEINDEX@0bn.Alldata] - _b[c.HLEINDEX@1.Alldata]



****Initial descriptives and comparisons of moderators for predictor and outcomes

**BAS-2 NV**
sum(BAS2NVT) if GENDERAAB ==0, detail
hist(BAS2NVT) if GENDERAAB ==0, frequency normal bin(15)
sum(BAS2NVT) if GENDERAAB ==1, detail
hist(BAS2NVT) if GENDERAAB ==1, frequency normal bin(15)
*Adjusted mean and SD by MCS weights and strata
svy: mean BAS2NVT, over(GENDERAAB)
*t-test difference for levels on the moderator unadjusted
ttest BAS2NVT, by(GENDERAAB)
*adjusted t-test
svy: mean BAS2NVT, over(GENDERAAB) coeflegend
lincom _b[c.BAS2NVT@0bn.GENDERAAB] - _b[c.BAS2NVT@1.GENDERAAB]


sum(BAS2NVT) if Pov60Med ==0, detail
hist(BAS2NVT) if Pov60Med ==0, frequency normal bin(15)
sum(BAS2NVT) if Pov60Med ==1, detail
hist(BAS2NVT) if Pov60Med ==1, frequency normal bin(15)
*Adjusted mean and SD by MCS weights and strata
svy: mean BAS2NVT, over(Pov60Med)
*t-test difference for levels on the moderator unadjusted
ttest BAS2NVT, by(Pov60Med)
*adjusted t-test
svy: mean BAS2NVT, over(Pov60Med) coeflegend
lincom _b[c.BAS2NVT@0bn.Pov60Med] - _b[c.BAS2NVT@1.Pov60Med]


**FSP total**
sum(FSPT) if GENDERAAB ==0, detail
hist(FSPT) if GENDERAAB ==0, frequency normal bin(10)
sum(FSPT) if GENDERAAB ==1, detail
hist(FSPT) if GENDERAAB ==1, frequency normal bin(10)
*Adjusted mean and SD by MCS weights and strata
svy: mean FSPT, over(GENDERAAB)
*t-test difference for levels on the moderator unadjusted
ttest FSPT, by(GENDERAAB)
*adjusted t-test
svy: mean FSPT, over(GENDERAAB) coeflegend
lincom _b[c.FSPT@0bn.GENDERAAB] - _b[c.FSPT@1.GENDERAAB]

sum(FSPT) if Pov60Med ==0, detail
hist(FSPT) if Pov60Med ==0, frequency normal bin(10)
sum(FSPT) if Pov60Med ==1, detail
hist(FSPT) if Pov60Med ==1, frequency normal bin(10)
*Adjusted mean and SD by MCS weights and strata
svy: mean FSPT, over(Pov60Med)
*t-test difference for levels on the moderator unadjusted
ttest FSPT, by(Pov60Med)
*adjusted t-test
svy: mean FSPT, over(Pov60Med) coeflegend
lincom _b[c.FSPT@0bn.Pov60Med] - _b[c.FSPT@1.Pov60Med]


**FSP Personal, social and emotional development
sum(PSE) if GENDERAAB ==0, detail
hist(PSE) if GENDERAAB ==0, frequency normal bin(28)
sum(PSE) if GENDERAAB ==1, detail
hist(PSE) if GENDERAAB ==1, frequency normal bin(28)
*Adjusted mean and SD by MCS weights and strata
svy: mean PSE, over(GENDERAAB)
*t-test difference for levels on the moderator unadjusted
ttest PSE, by(GENDERAAB)
*adjusted t-test
svy: mean PSE, over(GENDERAAB) coeflegend
lincom _b[c.PSE@0bn.GENDERAAB] - _b[c.PSE@1.GENDERAAB]

sum(PSE) if Pov60Med ==0, detail
hist(PSE) if Pov60Med ==0, frequency normal bin(28)
sum(PSE) if Pov60Med ==1, detail
hist(PSE) if Pov60Med ==1, frequency normal bin(28)
*Adjusted mean and SD by MCS weights and strata
svy: mean PSE, over(Pov60Med)
*t-test difference for levels on the moderator unadjusted
ttest PSE, by(Pov60Med)
*adjusted t-test
svy: mean PSE, over(Pov60Med) coeflegend
lincom _b[c.PSE@0bn.Pov60Med] - _b[c.PSE@1.Pov60Med]


**FSP Communication Language and Literacy development
sum(CLL) if GENDERAAB ==0, detail
hist(CLL) if GENDERAAB ==0, frequency normal bin(37)
sum(CLL) if GENDERAAB ==1, detail
hist(CLL) if GENDERAAB ==1, frequency normal bin(37)
*Adjusted mean and SD by MCS weights and strata
svy: mean CLL, over(GENDERAAB)
*t-test difference for levels on the moderator unadjusted
ttest CLL, by(GENDERAAB)
*adjusted t-test
svy: mean CLL, over(GENDERAAB) coeflegend
lincom _b[c.CLL@0bn.GENDERAAB] - _b[c.CLL@1.GENDERAAB]

sum(CLL) if Pov60Med ==0, detail
hist(CLL) if Pov60Med ==0, frequency normal bin(37)
sum(CLL) if Pov60Med ==1, detail
hist(CLL) if Pov60Med ==1, frequency normal bin(37)
*Adjusted mean and SD by MCS weights and strata
svy: mean CLL, over(Pov60Med)
*t-test difference for levels on the moderator unadjusted
ttest CLL, by(Pov60Med)
*adjusted t-test
svy: mean CLL, over(Pov60Med) coeflegend
lincom _b[c.CLL@0bn.Pov60Med] - _b[c.CLL@1.Pov60Med]


**FSP Mathematics development
sum(MD) if GENDERAAB ==0, detail
hist(MD) if GENDERAAB ==0, frequency normal bin(28)
sum(MD) if GENDERAAB ==1, detail
hist(MD) if GENDERAAB ==1, frequency normal bin(28)
*Adjusted mean and SD by MCS weights and strata
svy: mean MD, over(GENDERAAB)
*t-test difference for levels on the moderator unadjusted
ttest MD, by(GENDERAAB)
*adjusted t-test
svy: mean MD, over(GENDERAAB) coeflegend
lincom _b[c.MD@0bn.GENDERAAB] - _b[c.MD@1.GENDERAAB]

sum(MD) if Pov60Med ==0, detail
hist(MD) if Pov60Med ==0, frequency normal bin(28)
sum(MD) if Pov60Med ==1, detail
hist(MD) if Pov60Med ==1, frequency normal bin(28)
*Adjusted mean and SD by MCS weights and strata
svy: mean MD, over(Pov60Med)
*t-test difference for levels on the moderator unadjusted
ttest MD, by(Pov60Med)
*adjusted t-test
svy: mean MD, over(Pov60Med) coeflegend
lincom _b[c.MD@0bn.Pov60Med] - _b[c.MD@1.Pov60Med]


**FSP knowledge and understanding of the world
sum(KUW) if GENDERAAB ==0, detail
hist(KUW) if GENDERAAB ==0, frequency normal bin(10)
sum(KUW) if GENDERAAB ==1, detail
hist(KUW) if GENDERAAB ==1, frequency normal bin(10)
*Adjusted mean and SD by MCS weights and strata
svy: mean KUW, over(GENDERAAB)
*t-test difference for levels on the moderator unadjusted
ttest KUW, by(GENDERAAB)
*adjusted t-test
svy: mean KUW, over(GENDERAAB) coeflegend
lincom _b[c.KUW@0bn.GENDERAAB] - _b[c.KUW@1.GENDERAAB]

sum(KUW) if Pov60Med ==0, detail
hist(KUW) if Pov60Med ==0, frequency normal bin(10)
sum(KUW) if Pov60Med ==1, detail
hist(KUW) if Pov60Med ==1, frequency normal bin(10)
*Adjusted mean and SD by MCS weights and strata
svy: mean KUW, over(Pov60Med)
*t-test difference for levels on the moderator unadjusted
ttest KUW, by(Pov60Med)
*adjusted t-test
svy: mean KUW, over(Pov60Med) coeflegend
lincom _b[c.KUW@0bn.Pov60Med] - _b[c.KUW@1.Pov60Med]


**FSP physical development
sum(PD) if GENDERAAB ==0, detail
hist(PD) if GENDERAAB ==0, frequency normal bin(10)
sum(PD) if GENDERAAB ==1, detail
hist(PD) if GENDERAAB ==1, frequency normal bin(10)
*Adjusted mean and SD by MCS weights and strata
svy: mean PD, over(GENDERAAB)
*t-test difference for levels on the moderator unadjusted
ttest PD, by(GENDERAAB)
*adjusted t-test
svy: mean PD, over(GENDERAAB) coeflegend
lincom _b[c.PD@0bn.GENDERAAB] - _b[c.PD@1.GENDERAAB]

sum(PD) if Pov60Med ==0, detail
hist(PD) if Pov60Med ==0, frequency normal bin(10)
sum(PD) if Pov60Med ==1, detail
hist(PD) if Pov60Med ==1, frequency normal bin(10)
*Adjusted mean and SD by MCS weights and strata
svy: mean PD, over(Pov60Med)
*t-test difference for levels on the moderator unadjusted
ttest PD, by(Pov60Med)
*adjusted t-test
svy: mean PD, over(Pov60Med) coeflegend
lincom _b[c.PD@0bn.Pov60Med] - _b[c.PD@1.Pov60Med]


**FSP creative development
sum(CD) if GENDERAAB ==0, detail
hist(CD) if GENDERAAB ==0, frequency normal bin(10)
sum(CD) if GENDERAAB ==1, detail
hist(CD) if GENDERAAB ==1, frequency normal bin(10)
*Adjusted mean and SD by MCS weights and strata
svy: mean CD, over(GENDERAAB)
*t-test difference for levels on the moderator unadjusted
ttest CD, by(GENDERAAB)
*adjusted t-test
svy: mean CD, over(GENDERAAB) coeflegend
lincom _b[c.CD@0bn.GENDERAAB] - _b[c.CD@1.GENDERAAB]

sum(CD) if Pov60Med ==0, detail
hist(CD) if Pov60Med ==0, frequency normal bin(10)
sum(CD) if Pov60Med ==1, detail
hist(CD) if Pov60Med ==1, frequency normal bin(10)
*Adjusted mean and SD by MCS weights and strata
svy: mean CD, over(Pov60Med)
*t-test difference for levels on the moderator unadjusted
ttest CD, by(Pov60Med)
*adjusted t-test
svy: mean CD, over(Pov60Med) coeflegend
lincom _b[c.CD@0bn.Pov60Med] - _b[c.CD@1.Pov60Med]


**GLD**
*FSP GLD x Gender AAB
tab FSPGLD if GENDERAAB ==0
tab FSPGLD if GENDERAAB ==1
*Chi-square difference in gender AAB proportions between those with full and partial data
tab FSPGLD GENDERAAB, chi2 expected row
*chi-square adjusted 
svy: tabulate FSPGLD GENDERAAB, row

*FSP GLD x Relative poverty
tab FSPGLD if Pov60Med ==0
tab FSPGLD if Pov60Med ==1
*Chi-square difference in gender AAB proportions between those with full and partial data 
tab FSPGLD Pov60Med, chi2 expected row
*chi-square adjusted 
svy: tabulate FSPGLD Pov60Med, row



********************************************************************************
*****************************Final analysis*************************************
********************************************************************************

********************Linear regression assumptions*******************************

*1) linearity between independent and outcome variables and 2) homoscedasticity
scatter FSPT BAS2NVT || lfit FSPT BAS2NVT


*3) normality of residuals (kernel density, P-P and Q-Q plots)
**FSP total
regress FSPT c.BAS2NVT 
predict r, resid
kdensity r, normal
pnorm r
qnorm r

*4) no multicollinearity (via VIF and correlations)
**Correlations (This is complete cases only = n=5,718)
pwcorr FSPT FSPGLD PSE CLL MD KUW PD CD BAS2NVT GENDERAAB Pov60Med AgeMo BSRAR SDQT MatEdu MatAgeBirth MatMH HLEINDEX, bon listwise sig star(5) 
*Also checked with all cases (7,012) - not much difference in results
pwcorr FSPT FSPGLD PSE CLL MD KUW PD CD BAS2NVT GENDERAAB Pov60Med AgeMo BSRAR SDQT MatEdu MatAgeBirth MatMH HLEINDEX, bon sig star(5)
**VIF and tolerance
*Put Gender assigned at birth and poverty in as non-interactive because this would naturally make their VIF be massive 
regress FSPT c.BAS2NVT i.GENDERAAB i.Pov60Med c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX
vif

********************Logistic regression assumptions*****************************

*1) no multicollinearity (via spearman’s correlations)
*Multicolinearity
*No multicollineary found - no correaltions or spearmans over .6
spearman FSPGLD BAS2NVT GENDERAAB Pov60Med AgeMo BSRAR SDQT MatEdu MatAgeBirth MatMH HLEINDEX, bon stats(rho obs p) star(0.05)

*2) linearity between independent variables and log odds (via Box-Tidwell test) 
ssc install boxtid
boxtid logit FSPGLD c.BAS2NVT 
boxtid logit FSPGLD c.BAS2NVT##i.GENDERAAB 
boxtid logit FSPGLD c.BAS2NVT##i.Pov60Med
boxtid logit FSPGLD c.BAS2NVT##i.GENDERAAB i.Pov60Med c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX
boxtid logit FSPGLD c.BAS2NVT##i.Pov60Med i.GENDERAAB c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX

*non-linearity because most values are clustered very close together?
scatter FSPT AgeMo || lfit FSPT AgeMo

*Made no difference to significance - so 'outliers' are not likely issue
gen AgeMoSQR = sqrt(AgeMo)
boxtid logit FSPGLD c.BAS2NVT##i.GENDERAAB i.Pov60Med c.AgeMoSQR c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX
boxtid logit FSPGLD c.BAS2NVT##i.Pov60Med i.GENDERAAB c.AgeMoSQR c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX


***************************Extreme values***************************************

********LINEAR REGRESSION - FINAL MODELS (4 and 5)***********

******BOX PLOT OUTLIERS*********

*Trying to assess outliers via box plots
*Box graph - shows scores of 79 and 80 are outliers on the BAS-2 NV (n=69 full sample; n=59 those included in final analysis)
graph box BAS2NVT, mark(1, mlabel(BAS2NVT))
count if (BAS2NVT ==79) | (BAS2NVT ==80)
count if ((BAS2NVT ==79) | (BAS2NVT ==80)) & Alldata ==0
count if ((BAS2NVT ==79) | (BAS2NVT ==80)) & Alldata ==1


*Box graph - shows scors of 40 and under being outliers on the FSP (n=103 full sample)
graph box FSPT, mark(1, mlabel(FSPT))
count if FSPT <=40
count if (FSPT <=40) & Alldata ==1
count if (FSPT <=40) & Alldata ==0


*Getting means(SD) or proprotions for groups with BAS-2 outliers
sum BAS2NVT if ((BAS2NVT ==79) | (BAS2NVT ==80)) & Alldata ==1
sum FSPT if ((BAS2NVT ==79) | (BAS2NVT ==80)) & Alldata ==1
tab GENDERAAB if ((BAS2NVT ==79) | (BAS2NVT ==80)) & Alldata ==1
tab Pov60Med if ((BAS2NVT ==79) | (BAS2NVT ==80)) & Alldata ==1
sum AgeMo if ((BAS2NVT ==79) | (BAS2NVT ==80)) & Alldata ==1
sum BSRAR if ((BAS2NVT ==79) | (BAS2NVT ==80)) & Alldata ==1
sum SDQT if ((BAS2NVT ==79) | (BAS2NVT ==80)) & Alldata ==1
tab MatEdu if ((BAS2NVT ==79) | (BAS2NVT ==80)) & Alldata ==1
sum MatAgeBirth if ((BAS2NVT ==79) | (BAS2NVT ==80)) & Alldata ==1
sum MatMH if ((BAS2NVT ==79) | (BAS2NVT ==80)) & Alldata ==1
sum HLEINDEX if ((BAS2NVT ==79) | (BAS2NVT ==80)) & Alldata ==1

*Getting means(SD) or proprotions for groups with FSPT outliers
sum BAS2NVT if (FSPT <=40) & Alldata ==1
sum FSPT if (FSPT <=40) & Alldata ==1
tab GENDERAAB if (FSPT <=40) & Alldata ==1
tab Pov60Med if (FSPT <=40) & Alldata ==1
sum AgeMo if (FSPT <=40) & Alldata ==1
sum BSRAR if (FSPT <=40) & Alldata ==1
sum SDQT if (FSPT <=40) & Alldata ==1
tab MatEdu if (FSPT <=40) & Alldata ==1
sum MatAgeBirth if (FSPT <=40) & Alldata ==1
sum MatMH if (FSPT <=40) & Alldata ==1
sum HLEINDEX if (FSPT <=40) & Alldata ==1

*Getting means(SD) or proprotions for groups with BAS-2 and FSPT outliers
sum BAS2NVT if ((BAS2NVT ==79) | (BAS2NVT ==80) | (FSPT <=40)) & Alldata ==1
sum FSPT if ((BAS2NVT ==79) | (BAS2NVT ==80) | (FSPT <=40)) & Alldata ==1
tab GENDERAAB if ((BAS2NVT ==79) | (BAS2NVT ==80) | (FSPT <=40)) & Alldata ==1
tab Pov60Med if ((BAS2NVT ==79) | (BAS2NVT ==80) | (FSPT <=40)) & Alldata ==1
sum AgeMo if ((BAS2NVT ==79) | (BAS2NVT ==80) | (FSPT <=40)) & Alldata ==1
sum BSRAR if ((BAS2NVT ==79) | (BAS2NVT ==80) | (FSPT <=40)) & Alldata ==1
sum SDQT if ((BAS2NVT ==79) | (BAS2NVT ==80) | (FSPT <=40)) & Alldata ==1
tab MatEdu if ((BAS2NVT ==79) | (BAS2NVT ==80) | (FSPT <=40)) & Alldata ==1
sum MatAgeBirth if ((BAS2NVT ==79) | (BAS2NVT ==80) | (FSPT <=40)) & Alldata ==1
sum MatMH if ((BAS2NVT ==79) | (BAS2NVT ==80) | (FSPT <=40)) & Alldata ==1
sum HLEINDEX if ((BAS2NVT ==79) | (BAS2NVT ==80) | (FSPT <=40)) & Alldata ==1

*MODEL TESTING WITH BOX PLOT OUTLIERS
**Model 4
*Base model
reg FSPT c.BAS2NVT##i.GENDERAAB i.Pov60Med c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX
*Removal of FSPT and BAS-2 NV outliers (n=128 - all different children: no overlaps): Still significant, affects coefficient and sig for interaction noticably 
reg FSPT c.BAS2NVT##i.GENDERAAB i.Pov60Med c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX if ((BAS2NVT !=79) & (BAS2NVT !=80)) & FSPT >=41
*still significant when BAS-2 outliers removed (n=59)
reg FSPT c.BAS2NVT##i.GENDERAAB i.Pov60Med c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX if ((BAS2NVT !=79) & (BAS2NVT !=80))
*still significant when FSPT outliers removed (n=69), affects coefficient and sig for interaction noticably 
reg FSPT c.BAS2NVT##i.GENDERAAB i.Pov60Med c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX if FSPT >=41

**Model 5
*Base model 
reg FSPT c.BAS2NVT##i.Pov60Med i.GENDERAAB c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX
*Removal of FSPT and BAS-2 NV outliers (n=128 - all different children: no overlaps) - no changes except poverty becomes an ns individual predictor when both are removed
reg FSPT c.BAS2NVT##i.Pov60Med i.GENDERAAB c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX if ((BAS2NVT !=79) & (BAS2NVT !=80)) & FSPT >=41
*BAS-2 outliers removed (n=59) - no changes
reg FSPT c.BAS2NVT##i.Pov60Med i.GENDERAAB c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX if ((BAS2NVT !=79) & (BAS2NVT !=80))
*FSPT outliers removed (n=69) - no changes except poverty becomes an ns individual predictor when both are removed
reg FSPT c.BAS2NVT##i.Pov60Med i.GENDERAAB c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX if FSPT >=41


******COOK'S DISTANCE OUTLIERS*********

***Model 4 - 338 potential outliers
reg FSPT c.BAS2NVT##i.GENDERAAB i.Pov60Med c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX
predict d4, cooksd
sort d4
count if d4>4/5718 & d4 !=.

*Descriptives of each variable by model 4 outliers
sum BAS2NVT if d4>4/5718 & d4 !=.
sum FSPT if d4>4/5718 & d4 !=.
tab GENDERAAB if d4>4/5718 & d4 !=.
tab Pov60Med if d4>4/5718 & d4 !=.
sum AgeMo if d4>4/5718 & d4 !=.
sum BSRAR if d4>4/5718 & d4 !=.
sum SDQT if d4>4/5718 & d4 !=.
tab MatEdu if d4>4/5718 & d4 !=.
sum MatAgeBirth if d4>4/5718 & d4 !=.
sum MatMH if d4>4/5718 & d4 !=.
sum HLEINDEX if d4>4/5718 & d4 !=.

*Only real patterns seemed to relate to BAS-2 and FSPT scores being either different than expected from each other
list BAS2NVT FSPT d4 GENDERAAB Pov60Med AgeMo BSRAR SDQT MatEdu MatAgeBirth MatMH HLEINDEX if d4>4/5718 & d4 !=.

*Below BAS average T-score (same as sample mean)
count if d4>4/5718 & d4 !=. & BAS2NVT <=49
list BAS2NVT FSPT d4 if d4>4/5718 & d4 !=. & BAS2NVT <=49
*BAS-2 outliers (79 and 80 scores) 
count if d4>4/5718 & d4 !=. & BAS2NVT >=79
list BAS2NVT FSPT d4 if d4>4/5718 & d4 !=. & BAS2NVT >=79
*At or above average on FSPT 
count if d4>4/5718 & d4 !=. & FSPT <=88
list BAS2NVT FSPT d4 if d4>4/5718 & d4 !=. & FSPT <=88
*Below 78 threshold (as part of GLD)
count if d4>4/5718 & d4 !=. & FSPT <=77
list BAS2NVT FSPT d4 if d4>4/5718 & d4 !=. & FSPT <=78
*Outlier values from box plot for FSPT 
count if d4>4/5718 & d4 !=. & FSPT <=40
list BAS2NVT FSPT d4 if d4>4/5718 & d4 !=. & FSPT <=40
*At or above average for both variables - this was mostly kids with both high scores (close to or exceeds +1SD), around average BAS but really high FSPT scores, 1 case of +2SD BAS and average FSPT
count if d4>4/5718 & d4 !=. & BAS2NVT >=50  & FSPT >=88
list BAS2NVT FSPT d4 if d4>4/5718 & d4 !=. & BAS2NVT >=49  & FSPT >=88
*Below sample average for both BAS and FSPT 
count if d4>4/5718 & d4 !=. & BAS2NVT <=49  & FSPT <=87
*Below sample average for BAS and outlier FSPT 
count if d4>4/5718 & d4 !=. & BAS2NVT <=49 & FSPT <=40
*Average or higher for BAS and below sample average FSPT 
count if d4>4/5718 & d4 !=. & BAS2NVT >=50  & FSPT <=87
*Average or higher for BAS and outlier FSPT 
count if d4>4/5718 & d4 !=. & BAS2NVT >=50  & FSPT <=40

*Changes the model quite a bit - BAS, gender AAB, interaction, BSRAR, SDQ, Mat edu, HLE become insignificant
reg FSPT c.BAS2NVT##i.GENDERAAB i.Pov60Med c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX if d4>4/5718 & d4 !=.


***Model 5 - 347 potential outliers
reg FSPT c.BAS2NVT##i.Pov60Med i.GENDERAAB c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX
predict d5, cooksd
sort d5
count if d5>4/5718 & d5 !=.

sum BAS2NVT if d5>4/5718 & d5 !=.
sum FSPT if d5>4/5718 & d5 !=.
tab GENDERAAB if d5>4/5718 & d5 !=.
tab Pov60Med if d5>4/5718 & d5 !=.
sum AgeMo if d5>4/5718 & d5 !=.
sum BSRAR if d5>4/5718 & d5 !=.
sum SDQT if d5>4/5718 & d5 !=.
tab MatEdu if d5>4/5718 & d5 !=.
sum MatAgeBirth if d5>4/5718 & d5 !=.
sum MatMH if d5>4/5718 & d5 !=.
sum HLEINDEX if d5>4/5718 & d5 !=.

list BAS2NVT FSPT d5 GENDERAAB Pov60Med AgeMo BSRAR SDQT MatEdu MatAgeBirth MatMH HLEINDEX if d4>4/5718 & d5 !=.

*Below BAS average T-score (same as sample mean)
count if d5>4/5718 & d5 !=. & BAS2NVT <=49
list BAS2NVT FSPT d5 if d5>4/5718 & d5 !=. & BAS2NVT <=49
*BAS-2 outliers (79 and 80 scores) 
count if d5>4/5718 & d5 !=. & BAS2NVT >=79
list BAS2NVT FSPT d5 if d5>4/5718 & d5 !=. & BAS2NVT >=79
*At or above average on FSPT 
count if d5>4/5718 & d5 !=. & FSPT <=88
list BAS2NVT FSPT d5 if d5>4/5718 & d5 !=. & FSPT <=88
*Below 78 threshold (as part of GLD)
count if d5>4/5718 & d5 !=. & FSPT <=77
list BAS2NVT FSPT d5 if d5>4/5718 & d5 !=. & FSPT <=78
*Outlier values from box plot for FSPT 
count if d5>4/5718 & d5 !=. & FSPT <=40
list BAS2NVT FSPT d5 if d5>4/5718 & d5 !=. & FSPT <=40
*At or above average for both variables - this was mostly kids with both high scores (close to or exceeds +1SD), around average BAS but really high FSPT scores, 1 case of +2SD BAS and average FSPT
count if d5>4/5718 & d5 !=. & BAS2NVT >=50  & FSPT >=88
list BAS2NVT FSPT d5 if d5>4/5718 & d5 !=. & BAS2NVT >=49  & FSPT >=88
*Below sample average for both BAS and FSPT 
count if d5>4/5718 & d5 !=. & BAS2NVT <=49  & FSPT <=87
*Below sample average for BAS and outlier FSPT 
count if d5>4/5718 & d5 !=. & BAS2NVT <=49 & FSPT <=40
*Average or higher for BAS and below sample average FSPT 
count if d5>4/5718 & d5 !=. & BAS2NVT >=50  & FSPT <=87
*Average or higher for BAS and outlier FSPT 
count if d5>4/5718 & d5 !=. & BAS2NVT >=50  & FSPT <=40


*Makes language and poverty as well as a bunch of the covariates no longer predictors
reg FSPT c.BAS2NVT##i.Pov60Med i.GENDERAAB c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX if d5>4/5718 & d5 !=.


********LINEAR REGRESSION - FINAL MODELS (4 and 5)***********

********LEAST LIKELY CASES**************
*set-up
search leastlikely
*select and install st0022_1.pkg 


*Model 4
logit FSPGLD c.BAS2NVT##i.GENDERAAB i.Pov60Med c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX
leastlikely
*Model 5
logit FSPGLD c.BAS2NVT##i.Pov60Med i.GENDERAAB c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX
leastlikely
*Examined all of the children least likely (n=10) showed - All either achieved GLD and got low BAS-2 scores (at least -1SD, n=6, all but 1 female, all above 60% median), or did not achieve GLD and got above average BAS scores (at least +1SD, n=3, all below 60% median, male, 3 years old, -1SD and below BSRAR); n=1 had below average BAS and did not achieve GLD (female, above 60% median, -1SD BSRAR - so seemed to be an outlier for doing poorly despite being female and above poverty) 
list FSPGLD BAS2NVT GENDERAAB Pov60Med AgeMo BSRAR SDQT MatEdu MatAgeBirth MatMH HLEINDEX if MCSID == "M35638B" 
list FSPGLD BAS2NVT GENDERAAB Pov60Med AgeMo BSRAR SDQT MatEdu MatAgeBirth MatMH HLEINDEX if MCSID == "M10524L" 
list FSPGLD BAS2NVT GENDERAAB Pov60Med AgeMo BSRAR SDQT MatEdu MatAgeBirth MatMH HLEINDEX if MCSID == "M23975C" 
list FSPGLD BAS2NVT GENDERAAB Pov60Med AgeMo BSRAR SDQT MatEdu MatAgeBirth MatMH HLEINDEX if MCSID == "M10506J" 
list FSPGLD BAS2NVT GENDERAAB Pov60Med AgeMo BSRAR SDQT MatEdu MatAgeBirth MatMH HLEINDEX if MCSID == "M10315D" 
list FSPGLD BAS2NVT GENDERAAB Pov60Med AgeMo BSRAR SDQT MatEdu MatAgeBirth MatMH HLEINDEX if MCSID == "M13188C" 
list FSPGLD BAS2NVT GENDERAAB Pov60Med AgeMo BSRAR SDQT MatEdu MatAgeBirth MatMH HLEINDEX if MCSID == "M19212K" 
list FSPGLD BAS2NVT GENDERAAB Pov60Med AgeMo BSRAR SDQT MatEdu MatAgeBirth MatMH HLEINDEX if MCSID == "M21437X" 
list FSPGLD BAS2NVT GENDERAAB Pov60Med AgeMo BSRAR SDQT MatEdu MatAgeBirth MatMH HLEINDEX if MCSID == "M10513H" 
list FSPGLD BAS2NVT GENDERAAB Pov60Med AgeMo BSRAR SDQT MatEdu MatAgeBirth MatMH HLEINDEX if MCSID == "M22164W" 

*Model 4 without leastlikely outliers
logit FSPGLD c.BAS2NVT##i.GENDERAAB i.Pov60Med c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX if (MCSID != "M35638B" & MCSID != "M10524L" & MCSID != "M23975C" & MCSID != "M10506J" & MCSID != "M10315D" & MCSID != "M13188C" & MCSID != "M19212K" & MCSID != "M21437X" & MCSID != "M10513H" & MCSID != "M22164W")
*Model 5 without leastlikely outliers
logit FSPGLD c.BAS2NVT##i.Pov60Med i.GENDERAAB c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX if (MCSID != "M35638B" & MCSID != "M10524L" & MCSID != "M23975C" & MCSID != "M10506J" & MCSID != "M10315D" & MCSID != "M13188C" & MCSID != "M19212K" & MCSID != "M21437X" & MCSID != "M10513H" & MCSID != "M22164W")

********************************************************************************
**********************Final Regressions*****************************************
********************************************************************************

*Linear (FSP total, with robust SEs, continuous vars for covariates where applicable)
reg FSPT c.BAS2NVT, vce(robust)
reg FSPT c.BAS2NVT##i.GENDERAAB, vce(robust)
reg FSPT c.BAS2NVT##i.Pov60Med, vce(robust)
reg FSPT c.BAS2NVT##i.GENDERAAB i.Pov60Med c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX, vce(robust)
reg FSPT c.BAS2NVT##i.Pov60Med i.GENDERAAB c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX, vce(robust)
*Linear (FSP total, with survey weights, continuous vars for covariates where applicable)
svy: reg FSPT c.BAS2NVT  
svy: reg FSPT c.BAS2NVT##i.GENDERAAB 
svy: reg FSPT c.BAS2NVT##i.Pov60Med  
svy: reg FSPT c.BAS2NVT##i.GENDERAAB i.Pov60Med c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX 
svy: reg FSPT c.BAS2NVT##i.Pov60Med i.GENDERAAB c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX 

*Scatterplots by moderation levels
*If gender assigned at birth is impacting the linear relationship between BAS-2 NV and FSP - Average FSP score for each vocabulary score, split by gender assigned at birth level
bysort BAS2NVT: egen FSP_MEAN_Male = mean(FSPT) if GENDERAAB == 0
bysort BAS2NVT: egen FSP_MEAN_Female = mean(FSPT) if GENDERAAB == 1
*N=7,012
tw (scatter FSP_MEAN_Male BAS2NVT, mcolor(orange) msymbol(t)) (scatter FSP_MEAN_Female BAS2NVT, mcolor(purple) msymbol(o)) (lfit FSPT BAS2NVT, color(black)) (lfit FSPT BAS2NVT if GENDERAAB == 1, color(purple)) (lfit FSPT BAS2NVT if GENDERAAB == 0, color(orange)) 
*N=5,718
tw (scatter FSP_MEAN_Male BAS2NVT, mcolor(orange) msymbol(t)) (scatter FSP_MEAN_Female BAS2NVT, mcolor(purple) msymbol(o)) (lfit FSPT BAS2NVT, color(black)) (lfit FSPT BAS2NVT if GENDERAAB == 1, color(purple)) (lfit FSPT BAS2NVT if GENDERAAB == 0, color(orange)) if Alldata ==1


*If OECD 60% poverty median is impacting the linear relationship between BAS-2 NV and FSP - Average FSP score for each vocabulary score, split by 60% poverty median level
bysort BAS2NVT: egen FSP_MEAN_Below = mean(FSPT) if Pov60Med == 0
bysort BAS2NVT: egen FSP_MEAN_Above = mean(FSPT) if Pov60Med == 1
*N=6,946 (number of children with poverty data)
tw (scatter FSP_MEAN_Below BAS2NVT, mcolor(red) msymbol(t)) (scatter FSP_MEAN_Above BAS2NVT, mcolor(green) msymbol(o)) (lfit FSPT BAS2NVT, color(black)) (lfit FSPT BAS2NVT if Pov60Med == 1, color(green)) (lfit FSPT BAS2NVT if Pov60Med == 0, color(red)) if Pov60Med !=.
*N=5,718
tw (scatter FSP_MEAN_Below BAS2NVT, mcolor(red) msymbol(t)) (scatter FSP_MEAN_Above BAS2NVT, mcolor(green) msymbol(o)) (lfit FSPT BAS2NVT, color(black)) (lfit FSPT BAS2NVT if Pov60Med == 1, color(green)) (lfit FSPT BAS2NVT if Pov60Med == 0, color(red)) if Alldata ==1

*Logistic (GLD, continuous vars for covariates where applicable)
logit FSPGLD c.BAS2NVT, vce(robust) 
logistic FSPGLD c.BAS2NVT, vce(robust) 
logit FSPGLD c.BAS2NVT##i.GENDERAAB, vce(robust) 
logistic FSPGLD c.BAS2NVT##i.GENDERAAB, vce(robust) 
logit FSPGLD c.BAS2NVT##i.Pov60Med, vce(robust)
logistic FSPGLD c.BAS2NVT##i.Pov60Med, vce(robust) 
logit FSPGLD c.BAS2NVT##i.GENDERAAB i.Pov60Med c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX, vce(robust) 
logistic FSPGLD c.BAS2NVT##i.GENDERAAB i.Pov60Med c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX, vce(robust) 
logit FSPGLD c.BAS2NVT##i.Pov60Med i.GENDERAAB c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX, vce(robust) 
logistic FSPGLD c.BAS2NVT##i.Pov60Med i.GENDERAAB c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX, vce(robust) 
*Logistic (GLD, with survey weights, continuous vars for covariates where applicable)
svy: logit FSPGLD c.BAS2NVT  
svy: logistic FSPGLD c.BAS2NVT 
svy: logit FSPGLD c.BAS2NVT##i.GENDERAAB 
svy: logistic FSPGLD c.BAS2NVT##i.GENDERAAB
svy: logit FSPGLD c.BAS2NVT##i.Pov60Med 
svy: logistic FSPGLD c.BAS2NVT##i.Pov60Med
svy: logit FSPGLD c.BAS2NVT##i.GENDERAAB i.Pov60Med c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX 
svy: logistic FSPGLD c.BAS2NVT##i.GENDERAAB i.Pov60Med c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX 
svy: logit FSPGLD c.BAS2NVT##i.Pov60Med i.GENDERAAB c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX 
svy: logistic FSPGLD c.BAS2NVT##i.Pov60Med i.GENDERAAB c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX 

*Linear (FSP Personal, social and Emotional Development total, with robust SEs, continuous vars for covariates where applicable)
reg PSE c.BAS2NVT, vce(robust) 
reg PSE c.BAS2NVT##i.GENDERAAB, vce(robust) 
reg PSE c.BAS2NVT##i.Pov60Med, vce(robust) 
reg PSE c.BAS2NVT##i.GENDERAAB i.Pov60Med c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX, vce(robust) 
reg PSE c.BAS2NVT##i.Pov60Med i.GENDERAAB c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX, vce(robust) 
*Linear (FSP Personal, social and Emotional Development total, with survey weights, continuous vars for covariates where applicable)
svy: reg PSE c.BAS2NVT
svy: reg PSE c.BAS2NVT##i.GENDERAAB
svy: reg PSE c.BAS2NVT##i.Pov60Med
svy: reg PSE c.BAS2NVT##i.GENDERAAB i.Pov60Med c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX
svy: reg PSE c.BAS2NVT##i.Pov60Med i.GENDERAAB c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX

*Scatterplots by moderation levels
*If gender assigned at birth is impacting the linear relationship between BAS-2 NV and PSE- Average PSE score for each vocabulary score, split by gender assigned at birth level
bysort BAS2NVT: egen PSE_MEAN_Male = mean(PSE) if GENDERAAB == 0
bysort BAS2NVT: egen PSE_MEAN_Female = mean(PSE) if GENDERAAB == 1
tw (scatter PSE_MEAN_Male BAS2NVT, mcolor(orange) msymbol(t)) (scatter PSE_MEAN_Female BAS2NVT, mcolor(purple) msymbol(o)) (lfit PSE BAS2NVT, color(black)) (lfit PSE BAS2NVT if GENDERAAB == 1, color(purple)) (lfit PSE BAS2NVT if GENDERAAB == 0, color(orange)) 

*If OECD 60% poverty median is impacting the linear relationship between BAS-2 NV and PSE - Average PSE score for each vocabulary score, split by 60% poverty median level
bysort BAS2NVT: egen PSE_MEAN_Below = mean(PSE) if Pov60Med == 0
bysort BAS2NVT: egen PSE_MEAN_Above = mean(PSE) if Pov60Med == 1
tw (scatter PSE_MEAN_Below BAS2NVT, mcolor(red) msymbol(t)) (scatter PSE_MEAN_Above BAS2NVT, mcolor(green) msymbol(o)) (lfit PSE BAS2NVT, color(black)) (lfit PSE BAS2NVT if Pov60Med == 1, color(green)) (lfit PSE BAS2NVT if Pov60Med == 0, color(red)) 

*Linear (FSP Communication, Language and Literacy total, with robust SEs, continuous vars for covariates where applicable)
reg CLL c.BAS2NVT, vce(robust) 
reg CLL c.BAS2NVT##i.GENDERAAB, vce(robust) 
reg CLL c.BAS2NVT##i.Pov60Med, vce(robust) 
reg CLL c.BAS2NVT##i.GENDERAAB i.Pov60Med c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX, vce(robust) 
reg CLL c.BAS2NVT##i.Pov60Med i.GENDERAAB c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX, vce(robust) 
*Linear (FSP Communication, Language and Literacy total, with survey weights, continuous vars for covariates where applicable)
svy: reg CLL c.BAS2NVT
svy: reg CLL c.BAS2NVT##i.GENDERAAB
svy: reg CLL c.BAS2NVT##i.Pov60Med
svy: reg CLL c.BAS2NVT##i.GENDERAAB i.Pov60Med c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX
svy: reg CLL c.BAS2NVT##i.Pov60Med i.GENDERAAB c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX

*Scatterplots by moderation levels
*If gender assigned at birth is impacting the linear relationship between BAS-2 NV and CLL- Average CLL score for each vocabulary score, split by gender assigned at birth level
bysort BAS2NVT: egen CLL_MEAN_Male = mean(CLL) if GENDERAAB == 0
bysort BAS2NVT: egen CLL_MEAN_Female = mean(CLL) if GENDERAAB == 1
tw (scatter CLL_MEAN_Male BAS2NVT, mcolor(orange) msymbol(t)) (scatter CLL_MEAN_Female BAS2NVT, mcolor(purple) msymbol(o)) (lfit CLL BAS2NVT, color(black)) (lfit CLL BAS2NVT if GENDERAAB == 1, color(purple)) (lfit CLL BAS2NVT if GENDERAAB == 0, color(orange)) 

*If OECD 60% poverty median is impacting the linear relationship between BAS-2 NV and CLL - Average CLL score for each vocabulary score, split by 60% poverty median level
bysort BAS2NVT: egen CLL_MEAN_Below = mean(CLL) if Pov60Med == 0
bysort BAS2NVT: egen CLL_MEAN_Above = mean(CLL) if Pov60Med == 1
tw (scatter CLL_MEAN_Below BAS2NVT, mcolor(red) msymbol(t)) (scatter CLL_MEAN_Above BAS2NVT, mcolor(green) msymbol(o)) (lfit CLL BAS2NVT, color(black)) (lfit CLL BAS2NVT if Pov60Med == 1, color(green)) (lfit CLL BAS2NVT if Pov60Med == 0, color(red)) 

*Linear (FSP Mathematical development total, with robust SEs, continuous vars for covariates where applicable)
reg MD c.BAS2NVT, vce(robust) 
reg MD c.BAS2NVT##i.GENDERAAB, vce(robust) 
reg MD c.BAS2NVT##i.Pov60Med, vce(robust) 
reg MD c.BAS2NVT##i.GENDERAAB i.Pov60Med c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX, vce(robust) 
reg MD c.BAS2NVT##i.Pov60Med i.GENDERAAB c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX, vce(robust) 
*Linear (FSP Mathematical development total, with survey weights, continuous vars for covariates where applicable)
svy: reg MD c.BAS2NVT
svy: reg MD c.BAS2NVT##i.GENDERAAB
svy: reg MD c.BAS2NVT##i.Pov60Med
svy: reg MD c.BAS2NVT##i.GENDERAAB i.Pov60Med c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX
svy: reg MD c.BAS2NVT##i.Pov60Med i.GENDERAAB c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX

*Scatterplots by moderation levels
*If gender assigned at birth is impacting the linear relationship between BAS-2 NV and MD- Average MD score for each vocabulary score, split by gender assigned at birth level
bysort BAS2NVT: egen MD_MEAN_Male = mean(MD) if GENDERAAB == 0
bysort BAS2NVT: egen MD_MEAN_Female = mean(MD) if GENDERAAB == 1
tw (scatter MD_MEAN_Male BAS2NVT, mcolor(orange) msymbol(t)) (scatter MD_MEAN_Female BAS2NVT, mcolor(purple) msymbol(o)) (lfit MD BAS2NVT, color(black)) (lfit MD BAS2NVT if GENDERAAB == 1, color(purple)) (lfit MD BAS2NVT if GENDERAAB == 0, color(orange)) 

*If OECD 60% poverty median is impacting the linear relationship between BAS-2 NV and MD - Average MD score for each vocabulary score, split by 60% poverty median level
bysort BAS2NVT: egen MD_MEAN_Below = mean(MD) if Pov60Med == 0
bysort BAS2NVT: egen MD_MEAN_Above = mean(MD) if Pov60Med == 1
tw (scatter MD_MEAN_Below BAS2NVT, mcolor(red) msymbol(t)) (scatter MD_MEAN_Above BAS2NVT, mcolor(green) msymbol(o)) (lfit MD BAS2NVT, color(black)) (lfit MD BAS2NVT if Pov60Med == 1, color(green)) (lfit MD BAS2NVT if Pov60Med == 0, color(red)) 

*Linear (FSP Knowledge and Understanding of the World total, with robust SEs, continuous vars for covariates where applicable)
reg KUW c.BAS2NVT, vce(robust) 
reg KUW c.BAS2NVT##i.GENDERAAB, vce(robust) 
reg KUW c.BAS2NVT##i.Pov60Med, vce(robust) 
reg KUW c.BAS2NVT##i.GENDERAAB i.Pov60Med c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX, vce(robust) 
reg KUW c.BAS2NVT##i.Pov60Med i.GENDERAAB c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX, vce(robust) 
*Linear (FSP Knowledge and Understanding of the World total, with survey weights, continuous vars for covariates where applicable)
svy: reg KUW c.BAS2NVT 
svy: reg KUW c.BAS2NVT##i.GENDERAAB 
svy: reg KUW c.BAS2NVT##i.Pov60Med
svy: reg KUW c.BAS2NVT##i.GENDERAAB i.Pov60Med c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX
svy: reg KUW c.BAS2NVT##i.Pov60Med i.GENDERAAB c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX 

*Scatterplots by moderation levels
*If gender assigned at birth is impacting the linear relationship between BAS-2 NV and KUW- Average KUW score for each vocabulary score, split by gender assigned at birth level
bysort BAS2NVT: egen KUW_MEAN_Male = mean(KUW) if GENDERAAB == 0
bysort BAS2NVT: egen KUW_MEAN_Female = mean(KUW) if GENDERAAB == 1
tw (scatter KUW_MEAN_Male BAS2NVT, mcolor(orange) msymbol(t)) (scatter KUW_MEAN_Female BAS2NVT, mcolor(purple) msymbol(o)) (lfit KUW BAS2NVT, color(black)) (lfit KUW BAS2NVT if GENDERAAB == 1, color(purple)) (lfit KUW BAS2NVT if GENDERAAB == 0, color(orange)) 

*If OECD 60% poverty median is impacting the linear relationship between BAS-2 NV and KUW - Average KUW score for each vocabulary score, split by 60% poverty median level
bysort BAS2NVT: egen KUW_MEAN_Below = mean(KUW) if Pov60Med == 0
bysort BAS2NVT: egen KUW_MEAN_Above = mean(KUW) if Pov60Med == 1
tw (scatter KUW_MEAN_Below BAS2NVT, mcolor(red) msymbol(t)) (scatter KUW_MEAN_Above BAS2NVT, mcolor(green) msymbol(o)) (lfit KUW BAS2NVT, color(black)) (lfit KUW BAS2NVT if Pov60Med == 1, color(green)) (lfit KUW BAS2NVT if Pov60Med == 0, color(red)) 

*Linear (FSP Physical Development total, with robust SEs, continuous vars for covariates where applicable)
reg PD c.BAS2NVT, vce(robust) 
reg PD c.BAS2NVT##i.GENDERAAB, vce(robust) 
reg PD c.BAS2NVT##i.Pov60Med, vce(robust) 
reg PD c.BAS2NVT##i.GENDERAAB i.Pov60Med c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX, vce(robust) 
reg PD c.BAS2NVT##i.Pov60Med i.GENDERAAB c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX, vce(robust) 
*Linear (FSP Physical Development total, with survey weights, continuous vars for covariates where applicable)
svy: reg PD c.BAS2NVT
svy: reg PD c.BAS2NVT##i.GENDERAAB
svy: reg PD c.BAS2NVT##i.Pov60Med
svy: reg PD c.BAS2NVT##i.GENDERAAB i.Pov60Med c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX
svy: reg PD c.BAS2NVT##i.Pov60Med i.GENDERAAB c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX

*Scatterplots by moderation levels
*If gender assigned at birth is impacting the linear relationship between BAS-2 NV and PD- Average PD score for each vocabulary score, split by gender assigned at birth level
bysort BAS2NVT: egen PD_MEAN_Male = mean(PD) if GENDERAAB == 0
bysort BAS2NVT: egen PD_MEAN_Female = mean(PD) if GENDERAAB == 1
tw (scatter PD_MEAN_Male BAS2NVT, mcolor(orange) msymbol(t)) (scatter PD_MEAN_Female BAS2NVT, mcolor(purple) msymbol(o)) (lfit PD BAS2NVT, color(black)) (lfit PD BAS2NVT if GENDERAAB == 1, color(purple)) (lfit PD BAS2NVT if GENDERAAB == 0, color(orange)) 

*If OECD 60% poverty median is impacting the linear relationship between BAS-2 NV and PD - Average PD score for each vocabulary score, split by 60% poverty median level
bysort BAS2NVT: egen PD_MEAN_Below = mean(PD) if Pov60Med == 0
bysort BAS2NVT: egen PD_MEAN_Above = mean(PD) if Pov60Med == 1
tw (scatter PD_MEAN_Below BAS2NVT, mcolor(red) msymbol(t)) (scatter PD_MEAN_Above BAS2NVT, mcolor(green) msymbol(o)) (lfit PD BAS2NVT, color(black)) (lfit PD BAS2NVT if Pov60Med == 1, color(green)) (lfit PD BAS2NVT if Pov60Med == 0, color(red)) 

*Linear (FSP Creative Development total, with robust SEs, continuous vars for covariates where applicable)
reg CD c.BAS2NVT, vce(robust) 
reg CD c.BAS2NVT##i.GENDERAAB, vce(robust) 
reg CD c.BAS2NVT##i.Pov60Med, vce(robust) 
reg CD c.BAS2NVT##i.GENDERAAB i.Pov60Med c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX, vce(robust) 
reg CD c.BAS2NVT##i.Pov60Med i.GENDERAAB c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX, vce(robust) 
*Linear (FSP Creative Development total, with survey weights, continuous vars for covariates where applicable)
svy: reg CD c.BAS2NVT 
svy: reg CD c.BAS2NVT##i.GENDERAAB 
svy: reg CD c.BAS2NVT##i.Pov60Med 
svy: reg CD c.BAS2NVT##i.GENDERAAB i.Pov60Med c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX
svy: reg CD c.BAS2NVT##i.Pov60Med i.GENDERAAB c.AgeMo c.BSRAR c.SDQT i.MatEdu c.MatAgeBirth c.MatMH c.HLEINDEX

*Scatterplots by moderation levels
*If gender assigned at birth is impacting the linear relationship between BAS-2 NV and CD- Average CD score for each vocabulary score, split by gender assigned at birth level
bysort BAS2NVT: egen CD_MEAN_Male = mean(CD) if GENDERAAB == 0
bysort BAS2NVT: egen CD_MEAN_Female = mean(CD) if GENDERAAB == 1
tw (scatter CD_MEAN_Male BAS2NVT, mcolor(orange) msymbol(t)) (scatter CD_MEAN_Female BAS2NVT, mcolor(purple) msymbol(o)) (lfit CD BAS2NVT, color(black)) (lfit CD BAS2NVT if GENDERAAB == 1, color(purple)) (lfit CD BAS2NVT if GENDERAAB == 0, color(orange)) 

*If OECD 60% poverty median is impacting the linear relationship between BAS-2 NV and CD - Average CD score for each vocabulary score, split by 60% poverty median level
bysort BAS2NVT: egen CD_MEAN_Below = mean(CD) if Pov60Med == 0
bysort BAS2NVT: egen CD_MEAN_Above = mean(CD) if Pov60Med == 1
tw (scatter CD_MEAN_Below BAS2NVT, mcolor(red) msymbol(t)) (scatter CD_MEAN_Above BAS2NVT, mcolor(green) msymbol(o)) (lfit CD BAS2NVT, color(black)) (lfit CD BAS2NVT if Pov60Med == 1, color(green)) (lfit CD BAS2NVT if Pov60Med == 0, color(red)) 